.. contents::

Introduction
============

Base content classes for document management system.

Tests
=====

This add-on is tested using Travis CI. The current status of the add-on is :

.. image:: https://secure.travis-ci.org/collective/collective.dms.basecontent.png
    :target: http://travis-ci.org/collective/collective.dms.basecontent
